==> pmml-model-1.0.0-sources.jar: org/dmg/pmml/TimeAnchor.java <==

package org.dmg.pmml;

import java.math.BigInteger;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.lang.Equals;
import org.jvnet.jaxb2_commons.lang.EqualsStrategy;
import org.jvnet.jaxb2_commons.lang.HashCode;
import org.jvnet.jaxb2_commons.lang.HashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBEqualsStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBHashCodeStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}TimeCycle" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}TimeException" maxOccurs="2" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="type" type="{http://www.dmg.org/PMML-4_1}TIME-ANCHOR" />
 *       &lt;attribute name="offset" type="{http://www.dmg.org/PMML-4_1}INT-NUMBER" />
 *       &lt;attribute name="stepsize" type="{http://www.dmg.org/PMML-4_1}INT-NUMBER" />
 *       &lt;attribute name="displayName" type="{http://www.w3.org/2001/XMLSchema}anySimpleType" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "timeCycles",
    "timeExceptions"
})
@XmlRootElement(name = "TimeAnchor")
@Schema(min = Version.PMML_4_0)
public class TimeAnchor
    extends PMMLObject
    implements Equals, HashCode
{

    @XmlElement(name = "TimeCycle")
    protected List<TimeCycle> timeCycles;
    @XmlElement(name = "TimeException")
    protected List<TimeException> timeExceptions;
    @XmlAttribute(name = "type")
    protected TimeAnchorType type;
    @XmlAttribute(name = "offset")
    protected BigInteger offset;
    @XmlAttribute(name = "stepsize")
    protected BigInteger stepsize;
    @XmlAttribute(name = "displayName")
    @XmlSchemaType(name = "anySimpleType")
    protected String displayName;

    /**
     * Gets the value of the timeCycles property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the timeCycles property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getTimeCycles().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link TimeCycle }
     * 
     * 
     */
    public List<TimeCycle> getTimeCycles() {
        if (timeCycles == null) {
            timeCycles = new ArrayList<TimeCycle>();
        }
        return this.timeCycles;
    }

    /**
     * Gets the value of the timeExceptions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the timeExceptions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getTimeExceptions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link TimeException }
     * 
     * 
     */
    public List<TimeException> getTimeExceptions() {
        if (timeExceptions == null) {
            timeExceptions = new ArrayList<TimeException>();
        }
        return this.timeExceptions;
    }

    /**
     * Gets the value of the type property.
     * 
     * @return
     *     possible object is
     *     {@link TimeAnchorType }
     *     
     */
    public TimeAnchorType getType() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value
     *     allowed object is
     *     {@link TimeAnchorType }
     *     
     */
    public void setType(TimeAnchorType value) {
        this.type = value;
    }

    /**
     * Gets the value of the offset property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getOffset() {
        return offset;
    }

    /**
     * Sets the value of the offset property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setOffset(BigInteger value) {
        this.offset = value;
    }

    /**
     * Gets the value of the stepsize property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getStepsize() {
        return stepsize;
    }

    /**
     * Sets the value of the stepsize property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setStepsize(BigInteger value) {
        this.stepsize = value;
    }

    /**
     * Gets the value of the displayName property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDisplayName() {
        return displayName;
    }

    /**
     * Sets the value of the displayName property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDisplayName(String value) {
        this.displayName = value;
    }

    public boolean equals(ObjectLocator thisLocator, ObjectLocator thatLocator, Object object, EqualsStrategy strategy) {
        if (!(object instanceof TimeAnchor)) {
            return false;
        }
        if (this == object) {
            return true;
        }
        if (!super.equals(thisLocator, thatLocator, object, strategy)) {
            return false;
        }
        final TimeAnchor that = ((TimeAnchor) object);
        {
            List<TimeCycle> lhsTimeCycles;
            lhsTimeCycles = (((this.timeCycles!= null)&&(!this.timeCycles.isEmpty()))?this.getTimeCycles():null);
            List<TimeCycle> rhsTimeCycles;
            rhsTimeCycles = (((that.timeCycles!= null)&&(!that.timeCycles.isEmpty()))?that.getTimeCycles():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "timeCycles", lhsTimeCycles), LocatorUtils.property(thatLocator, "timeCycles", rhsTimeCycles), lhsTimeCycles, rhsTimeCycles)) {
                return false;
            }
        }
        {
            List<TimeException> lhsTimeExceptions;
            lhsTimeExceptions = (((this.timeExceptions!= null)&&(!this.timeExceptions.isEmpty()))?this.getTimeExceptions():null);
            List<TimeException> rhsTimeExceptions;
            rhsTimeExceptions = (((that.timeExceptions!= null)&&(!that.timeExceptions.isEmpty()))?that.getTimeExceptions():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "timeExceptions", lhsTimeExceptions), LocatorUtils.property(thatLocator, "timeExceptions", rhsTimeExceptions), lhsTimeExceptions, rhsTimeExceptions)) {
                return false;
            }
        }
        {
            TimeAnchorType lhsType;
            lhsType = this.getType();
            TimeAnchorType rhsType;
            rhsType = that.getType();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "type", lhsType), LocatorUtils.property(thatLocator, "type", rhsType), lhsType, rhsType)) {
                return false;
            }
        }
        {
            BigInteger lhsOffset;
            lhsOffset = this.getOffset();
            BigInteger rhsOffset;
            rhsOffset = that.getOffset();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "offset", lhsOffset), LocatorUtils.property(thatLocator, "offset", rhsOffset), lhsOffset, rhsOffset)) {
                return false;
            }
        }
        {
            BigInteger lhsStepsize;
            lhsStepsize = this.getStepsize();
            BigInteger rhsStepsize;
            rhsStepsize = that.getStepsize();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "stepsize", lhsStepsize), LocatorUtils.property(thatLocator, "stepsize", rhsStepsize), lhsStepsize, rhsStepsize)) {
                return false;
            }
        }
        {
            String lhsDisplayName;
            lhsDisplayName = this.getDisplayName();
            String rhsDisplayName;
            rhsDisplayName = that.getDisplayName();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "displayName", lhsDisplayName), LocatorUtils.property(thatLocator, "displayName", rhsDisplayName), lhsDisplayName, rhsDisplayName)) {
                return false;
            }
        }
        return true;
    }

    public boolean equals(Object object) {
        final EqualsStrategy strategy = JAXBEqualsStrategy.INSTANCE;
        return equals(null, null, object, strategy);
    }

    public int hashCode(ObjectLocator locator, HashCodeStrategy strategy) {
        int currentHashCode = super.hashCode(locator, strategy);
        {
            List<TimeCycle> theTimeCycles;
            theTimeCycles = (((this.timeCycles!= null)&&(!this.timeCycles.isEmpty()))?this.getTimeCycles():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "timeCycles", theTimeCycles), currentHashCode, theTimeCycles);
        }
        {
            List<TimeException> theTimeExceptions;
            theTimeExceptions = (((this.timeExceptions!= null)&&(!this.timeExceptions.isEmpty()))?this.getTimeExceptions():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "timeExceptions", theTimeExceptions), currentHashCode, theTimeExceptions);
        }
        {
            TimeAnchorType theType;
            theType = this.getType();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "type", theType), currentHashCode, theType);
        }
        {
            BigInteger theOffset;
            theOffset = this.getOffset();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "offset", theOffset), currentHashCode, theOffset);
        }
        {
            BigInteger theStepsize;
            theStepsize = this.getStepsize();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "stepsize", theStepsize), currentHashCode, theStepsize);
        }
        {
            String theDisplayName;
            theDisplayName = this.getDisplayName();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "displayName", theDisplayName), currentHashCode, theDisplayName);
        }
        return currentHashCode;
    }

    public int hashCode() {
        final HashCodeStrategy strategy = JAXBHashCodeStrategy.INSTANCE;
        return this.hashCode(null, strategy);
    }

}

==> pmml-model-1.0.2-sources.jar: org/dmg/pmml/TimeAnchor.java <==

package org.dmg.pmml;

import java.math.BigInteger;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.lang.Equals;
import org.jvnet.jaxb2_commons.lang.EqualsStrategy;
import org.jvnet.jaxb2_commons.lang.HashCode;
import org.jvnet.jaxb2_commons.lang.HashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBEqualsStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBHashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}TimeCycle" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}TimeException" maxOccurs="2" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="type" type="{http://www.dmg.org/PMML-4_1}TIME-ANCHOR" />
 *       &lt;attribute name="offset" type="{http://www.dmg.org/PMML-4_1}INT-NUMBER" />
 *       &lt;attribute name="stepsize" type="{http://www.dmg.org/PMML-4_1}INT-NUMBER" />
 *       &lt;attribute name="displayName" type="{http://www.w3.org/2001/XMLSchema}anySimpleType" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "timeCycles",
    "timeExceptions"
})
@XmlRootElement(name = "TimeAnchor")
@Schema(min = Version.PMML_4_0)
public class TimeAnchor
    extends PMMLObject
    implements Equals, HashCode, ToString
{

    @XmlElement(name = "TimeCycle")
    protected List<TimeCycle> timeCycles;
    @XmlElement(name = "TimeException")
    protected List<TimeException> timeExceptions;
    @XmlAttribute(name = "type")
    protected TimeAnchorType type;
    @XmlAttribute(name = "offset")
    protected BigInteger offset;
    @XmlAttribute(name = "stepsize")
    protected BigInteger stepsize;
    @XmlAttribute(name = "displayName")
    @XmlSchemaType(name = "anySimpleType")
    protected String displayName;

    /**
     * Gets the value of the timeCycles property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the timeCycles property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getTimeCycles().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link TimeCycle }
     * 
     * 
     */
    public List<TimeCycle> getTimeCycles() {
        if (timeCycles == null) {
            timeCycles = new ArrayList<TimeCycle>();
        }
        return this.timeCycles;
    }

    /**
     * Gets the value of the timeExceptions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the timeExceptions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getTimeExceptions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link TimeException }
     * 
     * 
     */
    public List<TimeException> getTimeExceptions() {
        if (timeExceptions == null) {
            timeExceptions = new ArrayList<TimeException>();
        }
        return this.timeExceptions;
    }

    /**
     * Gets the value of the type property.
     * 
     * @return
     *     possible object is
     *     {@link TimeAnchorType }
     *     
     */
    public TimeAnchorType getType() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value
     *     allowed object is
     *     {@link TimeAnchorType }
     *     
     */
    public void setType(TimeAnchorType value) {
        this.type = value;
    }

    /**
     * Gets the value of the offset property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getOffset() {
        return offset;
    }

    /**
     * Sets the value of the offset property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setOffset(BigInteger value) {
        this.offset = value;
    }

    /**
     * Gets the value of the stepsize property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getStepsize() {
        return stepsize;
    }

    /**
     * Sets the value of the stepsize property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setStepsize(BigInteger value) {
        this.stepsize = value;
    }

    /**
     * Gets the value of the displayName property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDisplayName() {
        return displayName;
    }

    /**
     * Sets the value of the displayName property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDisplayName(String value) {
        this.displayName = value;
    }

    public boolean equals(ObjectLocator thisLocator, ObjectLocator thatLocator, Object object, EqualsStrategy strategy) {
        if (!(object instanceof TimeAnchor)) {
            return false;
        }
        if (this == object) {
            return true;
        }
        if (!super.equals(thisLocator, thatLocator, object, strategy)) {
            return false;
        }
        final TimeAnchor that = ((TimeAnchor) object);
        {
            List<TimeCycle> lhsTimeCycles;
            lhsTimeCycles = (((this.timeCycles!= null)&&(!this.timeCycles.isEmpty()))?this.getTimeCycles():null);
            List<TimeCycle> rhsTimeCycles;
            rhsTimeCycles = (((that.timeCycles!= null)&&(!that.timeCycles.isEmpty()))?that.getTimeCycles():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "timeCycles", lhsTimeCycles), LocatorUtils.property(thatLocator, "timeCycles", rhsTimeCycles), lhsTimeCycles, rhsTimeCycles)) {
                return false;
            }
        }
        {
            List<TimeException> lhsTimeExceptions;
            lhsTimeExceptions = (((this.timeExceptions!= null)&&(!this.timeExceptions.isEmpty()))?this.getTimeExceptions():null);
            List<TimeException> rhsTimeExceptions;
            rhsTimeExceptions = (((that.timeExceptions!= null)&&(!that.timeExceptions.isEmpty()))?that.getTimeExceptions():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "timeExceptions", lhsTimeExceptions), LocatorUtils.property(thatLocator, "timeExceptions", rhsTimeExceptions), lhsTimeExceptions, rhsTimeExceptions)) {
                return false;
            }
        }
        {
            TimeAnchorType lhsType;
            lhsType = this.getType();
            TimeAnchorType rhsType;
            rhsType = that.getType();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "type", lhsType), LocatorUtils.property(thatLocator, "type", rhsType), lhsType, rhsType)) {
                return false;
            }
        }
        {
            BigInteger lhsOffset;
            lhsOffset = this.getOffset();
            BigInteger rhsOffset;
            rhsOffset = that.getOffset();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "offset", lhsOffset), LocatorUtils.property(thatLocator, "offset", rhsOffset), lhsOffset, rhsOffset)) {
                return false;
            }
        }
        {
            BigInteger lhsStepsize;
            lhsStepsize = this.getStepsize();
            BigInteger rhsStepsize;
            rhsStepsize = that.getStepsize();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "stepsize", lhsStepsize), LocatorUtils.property(thatLocator, "stepsize", rhsStepsize), lhsStepsize, rhsStepsize)) {
                return false;
            }
        }
        {
            String lhsDisplayName;
            lhsDisplayName = this.getDisplayName();
            String rhsDisplayName;
            rhsDisplayName = that.getDisplayName();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "displayName", lhsDisplayName), LocatorUtils.property(thatLocator, "displayName", rhsDisplayName), lhsDisplayName, rhsDisplayName)) {
                return false;
            }
        }
        return true;
    }

    public boolean equals(Object object) {
        final EqualsStrategy strategy = JAXBEqualsStrategy.INSTANCE;
        return equals(null, null, object, strategy);
    }

    public int hashCode(ObjectLocator locator, HashCodeStrategy strategy) {
        int currentHashCode = super.hashCode(locator, strategy);
        {
            List<TimeCycle> theTimeCycles;
            theTimeCycles = (((this.timeCycles!= null)&&(!this.timeCycles.isEmpty()))?this.getTimeCycles():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "timeCycles", theTimeCycles), currentHashCode, theTimeCycles);
        }
        {
            List<TimeException> theTimeExceptions;
            theTimeExceptions = (((this.timeExceptions!= null)&&(!this.timeExceptions.isEmpty()))?this.getTimeExceptions():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "timeExceptions", theTimeExceptions), currentHashCode, theTimeExceptions);
        }
        {
            TimeAnchorType theType;
            theType = this.getType();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "type", theType), currentHashCode, theType);
        }
        {
            BigInteger theOffset;
            theOffset = this.getOffset();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "offset", theOffset), currentHashCode, theOffset);
        }
        {
            BigInteger theStepsize;
            theStepsize = this.getStepsize();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "stepsize", theStepsize), currentHashCode, theStepsize);
        }
        {
            String theDisplayName;
            theDisplayName = this.getDisplayName();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "displayName", theDisplayName), currentHashCode, theDisplayName);
        }
        return currentHashCode;
    }

    public int hashCode() {
        final HashCodeStrategy strategy = JAXBHashCodeStrategy.INSTANCE;
        return this.hashCode(null, strategy);
    }

    public String toString() {
        final ToStringStrategy strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        super.appendFields(locator, buffer, strategy);
        {
            List<TimeCycle> theTimeCycles;
            theTimeCycles = (((this.timeCycles!= null)&&(!this.timeCycles.isEmpty()))?this.getTimeCycles():null);
            strategy.appendField(locator, this, "timeCycles", buffer, theTimeCycles);
        }
        {
            List<TimeException> theTimeExceptions;
            theTimeExceptions = (((this.timeExceptions!= null)&&(!this.timeExceptions.isEmpty()))?this.getTimeExceptions():null);
            strategy.appendField(locator, this, "timeExceptions", buffer, theTimeExceptions);
        }
        {
            TimeAnchorType theType;
            theType = this.getType();
            strategy.appendField(locator, this, "type", buffer, theType);
        }
        {
            BigInteger theOffset;
            theOffset = this.getOffset();
            strategy.appendField(locator, this, "offset", buffer, theOffset);
        }
        {
            BigInteger theStepsize;
            theStepsize = this.getStepsize();
            strategy.appendField(locator, this, "stepsize", buffer, theStepsize);
        }
        {
            String theDisplayName;
            theDisplayName = this.getDisplayName();
            strategy.appendField(locator, this, "displayName", buffer, theDisplayName);
        }
        return buffer;
    }

}
